Coverage for manage.py: 80%

# Coverage for manage.py : 80%

## 10 statements

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1#!/usr/bin/env python

2"""Django's command-line utility for administrative tasks."""

3 import os

4 import sys

5

6

7 def main():

8 os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'project.settings')

9 try:

10 from django.core.management import execute_from_command_line # pylint: disable=import-outside-toplevel

11 except ImportError as exc:

12 raise ImportError(

13 "Couldn't import Django. Are you sure it's installed and "

14 "available on your PYTHONPATH environment variable? Did you "

15 "forget to activate a virtual environment?"

16 ) from exc

17 execute_from_command_line(sys.argv)

18

19

20 if __name__ == '__main__':

21 main()